<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * OptionLicense
 *
 * @package MailWizz EMA
 * @author Serban George Cristian <cristian.serban@mailwizz.com>
 * @link https://www.mailwizz.com/
 * @copyright MailWizz EMA (https://www.mailwizz.com)
 * @license https://www.mailwizz.com/license/
 * @since 1.3.4.9
 */

class OptionLicense extends OptionBase
{
    // settings category
    protected $_categoryName = 'system.license';

    public $market_place;

    public $purchase_code;

    private $_displayPurchaseCode;

    private $_initPurchaseCode;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        $rules = array(
            array('market_place, displayPurchaseCode', 'required'),
            array('market_place, displayPurchaseCode', 'length', 'max' => 255),
        );

        return CMap::mergeArray($rules, parent::rules());
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        $labels = array(
            'market_place'        => Yii::t('settings', 'Market place'),
            'purchase_code'       => Yii::t('settings', 'Purchase code'),
            'displayPurchaseCode' => Yii::t('settings', 'Purchase code'),
        );

        return CMap::mergeArray($labels, parent::attributeLabels());
    }

    /**
     * @inheritdoc
     */
    public function attributeHelpTexts()
    {
        $texts = array();
        return CMap::mergeArray($texts, parent::attributeHelpTexts());
    }

    /**
     * @return array
     */
    public function getMarketplacesList()
    {
        return array(
            'envato'    => Yii::t('settings', 'Envato Market Places'),
            'mailwizz'  => Yii::t('settings', 'Mailwizz Website'),
        );
    }

    /**
     * @param $code
     */
    public function setDisplayPurchaseCode($code)
    {
        $this->_displayPurchaseCode = $code;
    }

    /**
     * @return string
     */
    public function getDisplayPurchaseCode()
    {
        if (!empty($this->_displayPurchaseCode)) {
            return (string)$this->_displayPurchaseCode;
        }

        return StringHelper::maskStringEnding($this->purchase_code);
    }

    /**
     * @return mixed
     */
    public function getPurchaseCode()
    {
        return (string)$this->purchase_code;
    }

    /**
     * @return string
     */
    public function getMissingPurchaseCodeMessage()
    {
        return file_get_contents(Yii::getPathOfAlias('common.data.license.missing-purchase-code') . '.php');
    }

    /**
     * @return string
     */
    public function getCurrentPurchaseCode()
    {
        $displayPurchaseCode = $this->_displayPurchaseCode;
        $initPurchaseCode    = $this->_initPurchaseCode;
        $isAlreadyMasked     = str_repeat('x', 10) === substr(strtolower($displayPurchaseCode), -10);

        if ($isAlreadyMasked) {
            return $initPurchaseCode;
        }

        if ($displayPurchaseCode === StringHelper::maskStringEnding($initPurchaseCode)) {
            return $initPurchaseCode;
        }

        return $displayPurchaseCode;
    }

    /**
     * @return void
     */
    protected function afterConstruct()
    {
        parent::afterConstruct();
        $this->_initPurchaseCode = $this->purchase_code;
    }

    /**
     * @inheritDoc
     */
    protected function beforeValidate()
    {
        $this->purchase_code = $this->getCurrentPurchaseCode();

        return parent::beforeValidate();
    }
}
